"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const axios_1 = tslib_1.__importDefault(require("axios"));
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const constant_1 = tslib_1.__importDefault(require("../config/constant"));
const Application_1 = require("../libs/Application");
class Api extends Application_1.JKUtil {
    get token() {
        var _a, _b, _c, _d;
        (_b = (_a = this.ctx) === null || _a === void 0 ? void 0 : _a.Token) === null || _b === void 0 ? void 0 : _b.load();
        return ((_d = (_c = this.ctx) === null || _c === void 0 ? void 0 : _c.Token) === null || _d === void 0 ? void 0 : _d.token) || "";
    }
    handle(res, url, headers = {}, method, postData = {}) {
        var _a, _b, _c;
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { code, data, message = "" } = (_a = res === null || res === void 0 ? void 0 : res.data) !== null && _a !== void 0 ? _a : {};
            if (code === 0) {
                return data;
            }
            else if (code === 401) {
                yield ((_c = (_b = this.ctx) === null || _b === void 0 ? void 0 : _b.Auth) === null || _c === void 0 ? void 0 : _c.confirm());
                return yield this[method](url, headers, postData);
            }
            else {
                throw new Error(chalk_1.default.red(message));
            }
        });
    }
    /**
     * get method
     * @param url
     * @param headers
     * @returns
     */
    get(url, headers = {}) {
        return axios_1.default({
            url: `${constant_1.default === null || constant_1.default === void 0 ? void 0 : constant_1.default.PREFIX}${url}`,
            method: "get",
            headers: Object.assign(Object.assign({}, headers), { "Content-Type": "application/json", Authorization: `Bearer ${this.token}` }),
        }).then((res) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.handle(res, url, headers, "get");
        }));
    }
    /**
     * delete method
     * @param url
     * @param headers
     * @returns
     */
    delete(url, headers = {}) {
        return axios_1.default({
            url: `${constant_1.default === null || constant_1.default === void 0 ? void 0 : constant_1.default.PREFIX}${url}`,
            method: "delete",
            headers: Object.assign(Object.assign({}, headers), { "Content-Type": "application/json", Authorization: `Bearer ${this.token}` }),
        }).then((res) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.handle(res, url, headers, "delete");
        }));
    }
    /**
     * post method
     * @param url
     * @param headers
     * @param data
     * @returns
     */
    post(url, headers = {}, data = {}) {
        return axios_1.default({
            method: "post",
            data,
            url: `${constant_1.default === null || constant_1.default === void 0 ? void 0 : constant_1.default.PREFIX}${url}`,
            headers: Object.assign(Object.assign({}, headers), { "Content-Type": "application/json", Authorization: `Bearer ${this.token}` }),
        }).then((res) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.handle(res, url, headers, "post", data);
        }));
    }
    /**
     * put method
     * @param url
     * @param headers
     * @param data
     * @returns
     */
    put(url, headers = {}, data = {}) {
        return axios_1.default({
            method: "put",
            data,
            url: `${constant_1.default === null || constant_1.default === void 0 ? void 0 : constant_1.default.PREFIX}${url}`,
            headers: Object.assign(Object.assign({}, headers), { "Content-Type": "application/json", Authorization: `Bearer ${this.token}` }),
        }).then((res) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.handle(res, url, headers, "put", data);
        }));
    }
    /**
     * user
     */
    user() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return yield this.get("/user");
        });
    }
    /**
     * fragments
     */
    fragments() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return yield this.get("/fragments?pageSize=100");
        });
    }
    /**
     * saveGroup
     */
    saveGroup(values) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return yield this.post("/group", {}, values);
        });
    }
    /**
     * saveGroup
     */
    updateGroup(id, values) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return yield this.put(`/group/${id}`, {}, values);
        });
    }
    /**
     * saveGroup
     */
    groupLists() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return yield this.get("/groups?pageSize=100");
        });
    }
    /**
     * saveGroup
     */
    group(id) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return yield this.get(`/group/${id}`);
        });
    }
    /**
     * ids
     */
    ids() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return yield this.get("/recommends?pageSize=1000");
        });
    }
    /**
     * remove
     */
    remove(id) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return yield this.delete(`/group/${id}`);
        });
    }
    /**
     * remove
     */
    getOneById(id) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return yield this.get(`/group/${id}`);
        });
    }
}
exports.default = Api;
