"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const inquirer_confirm_1 = tslib_1.__importDefault(require("inquirer-confirm"));
const Application_1 = require("../libs/Application");
class Form extends Application_1.JKUtil {
    confirm(title = "yes|no") {
        return new Promise((resolve, reject) => {
            inquirer_confirm_1.default(title).then(function confirmed() {
                resolve("yes");
            }, function cancelled() {
                reject("no");
            });
        });
    }
    /**
     * input
     */
    input(props = {}) {
        const { defaultValue, message = "please input:", required = true, check } = props;
        return new Promise((resolve, reject) => {
            inquirer_1.default
                .prompt([
                {
                    message,
                    default: defaultValue,
                    name: "input",
                    type: "input",
                },
            ])
                .then((res) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                const name = res.input.toString();
                if (!name && !defaultValue && required) {
                    try {
                        const result = yield this.input(props);
                        resolve(result);
                    }
                    catch (error) {
                        reject(error);
                    }
                }
                if (name && check) {
                    try {
                        yield check(name);
                    }
                    catch (_error) {
                        console.log(chalk_1.default.green(_error));
                        try {
                            const result = yield this.input(props);
                            resolve(result);
                        }
                        catch (error) {
                            reject(error);
                        }
                    }
                }
                resolve(name);
            }))
                .catch((err) => {
                reject(err);
            });
        });
    }
    /**
     * list
     */
    list(props) {
        const { choices = [], message = "please choose:", defaultValue } = props;
        return new Promise((resolve, reject) => {
            inquirer_1.default
                .prompt([
                {
                    choices,
                    message,
                    type: "list",
                    default: defaultValue,
                    name: "input",
                },
            ])
                .then((res) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                resolve(res.input);
            }))
                .catch((error) => {
                reject(error);
            });
        });
    }
    /**
     * edit
     */
    edit({ message = "please input:", defaultValue = "" }) {
        return new Promise((resolve, reject) => {
            inquirer_1.default
                .prompt([
                {
                    message,
                    default: defaultValue,
                    type: "editor",
                    name: "input",
                },
            ])
                .then((res) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                resolve(res.input);
            }))
                .catch((error) => {
                reject(error);
            });
        });
    }
}
exports.default = Form;
