"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Global = exports.Inject = exports.Command = exports.JKUtil = exports.JKModule = void 0;
const tslib_1 = require("tslib");
const Exector_1 = tslib_1.__importDefault(require("./Exector"));
/**
 * 主应用
 */
class Application extends Exector_1.default {
    constructor() {
        super();
        this.commands = new Map();
        this.$providers = [];
        this.globalProviders = new Map();
        this.mudules = {};
        /**
         * 命令注册
         * @param options
         * @returns
         */
        this.Command = (options) => {
            return (target) => {
                const { providers = [] } = options, configs = tslib_1.__rest(options, ["providers"]);
                target.$providers = providers;
                for (const i of Object.keys(configs)) {
                    target.prototype[i] = options[i];
                }
                this.commands.set(target.name, target);
            };
        };
        /**
         * 方法注册
         * @param module
         * @returns
         */
        this.Inject = (modules) => {
            return (target) => {
                for (const i of modules) {
                    target.prototype[i.name] = () => {
                        return this.globalProviders.get(i.name);
                    };
                }
            };
        };
        /**
         * 全局模块引用
         * @param module
         * @returns
         */
        this.Global = (module) => {
            return (target, key) => {
                target[key] = this.globalProviders.get(module);
            };
        };
    }
    /**
     * 全局模块注册
     * @param provider
     */
    providers(provider) {
        if (Array.isArray(provider)) {
            this.$providers = [...this.$providers, ...provider];
        }
        else {
            this.$providers = [...this.$providers, provider];
        }
        return this;
    }
    start() {
        this.initGlobal();
        this.loadModules();
        this.initCommands();
    }
}
class JKModule {
}
exports.JKModule = JKModule;
class JKUtil {
}
exports.JKUtil = JKUtil;
const app = new Application();
exports.Command = app.Command;
exports.Inject = app.Inject;
exports.Global = app.Global;
exports.default = app;
